@@ -12,6 +12,8 @@ from deskbar.core.DeskbarHistory import DeskbarHistory
 from deskbar.core.ThreadPool import ThreadPool
 import deskbar.interfaces
 
+LOGGER = logging.getLogger(__name__)
+
 class CoreImpl(deskbar.interfaces.Core):
     
     DEFAULT_KEYBINDING = "<Alt>F3"
@@ -157,9 +159,9 @@ class CoreImpl(deskbar.interfaces.Core):
         """
         self._gconf.set_keybinding(binding)
         if not self._keybinder.bind(binding):
-            logging.error("Keybinding is already in use")
+            LOGGER.error("Keybinding is already in use")
         else:
-            logging.info("Successfully binded Deskbar to %s" % binding)
+            LOGGER.info("Successfully binded Deskbar to %s" % binding)
     
     def set_min_chars(self, number):
         self._gconf.set_min_chars(number)
@@ -237,6 +239,13 @@ class CoreImpl(deskbar.interfaces.Core):
         else:
             self._module_loader.initialize_module(module)
         self._module_list.increase_bottom_enabled_path()
+
+    def reload_all_modules(self):
+        self._module_list.clear()
+        self._disabled_module_list.clear()
+        LOGGER.info("Reloading all modules")
+        self._module_loader.emit("modules-reloading")
+        self._module_loader.load_all()
     
     def stop_queries(self):
         self._stop_queries = True
@@ -337,4 +346,4 @@ class CoreImpl(deskbar.interfaces.Core):
     def forward_query_ready(self, handler, query, matches):
         if query == self._last_query and matches != None and len(matches) > 0 and not self._stop_queries:
             self._emit_query_ready(matches)
-        
\ No newline at end of file
+        
