@@ -1,7 +1,6 @@
 import gtk
 import gtk.gdk
 import gtk.glade
-import gobject
 import traceback
 from gettext import gettext as _
 from os.path import join
@@ -75,6 +74,9 @@ class DeskbarPreferences:
         self.more_button.set_sensitive(False)
         self.more_button.connect("clicked", self.on_more_button_clicked)
         self.more_button_callback = None
+        self.reload_button = self.glade.get_widget("reload")
+        self.reload_button.connect("clicked", self.on_reload_button_clicked)
+        self.reload_button.set_tooltip_text(_("Reload all extensions"))
 
         # Info are at the bottom
         self.info_area = self.glade.get_widget("info_area")
@@ -221,13 +223,15 @@ class DeskbarPreferences:
     def on_more_button_clicked(self, button):
         if self.more_button_callback != None:
             self.more_button_callback(self.dialog)
+
+    def on_reload_button_clicked(self, button):
+        self._model.reload_all_modules()
     
     def on_module_selected(self, selection):
         module_context = self.moduleview.get_selected_module()
         
         if module_context != None:
             self.check_requirements(module_context)
-            gobject.timeout_add(1000, self.poll_requirements, module_context)
             
         # Check if we can update
         if self.newstuff != None:
@@ -237,41 +241,39 @@ class DeskbarPreferences:
     def set_buttons(self, selection):
         model, iter = selection.get_selected()
         if iter == None:
+            self.__set_top_buttons_sensitive(False)
+            self.__set_buttom_buttons_sensitive(False)
             return
         sensitive = model.is_module_enabled(iter)
         if sensitive:
             path = model.get_path(iter)
             path_first = model.get_path(model.get_iter_first())
             up = not (path == path_first)
-            self.button_top.set_sensitive(up)
-            self.button_up.set_sensitive(up)
+            self.__set_top_buttons_sensitive(up)
             iter_next = model.iter_next(iter)
             down = not (iter_next == None or not model.is_module_enabled(iter_next))
-            self.button_down.set_sensitive(down)
-            self.button_bottom.set_sensitive(down)
+            self.__set_buttom_buttons_sensitive(down)
         else:
-            self.button_top.set_sensitive(sensitive)
-            self.button_up.set_sensitive(sensitive)
-            self.button_down.set_sensitive(sensitive)
-            self.button_bottom.set_sensitive(sensitive)
+            self.__set_top_buttons_sensitive(sensitive)
+            self.__set_buttom_buttons_sensitive(sensitive)
+    
+    def __set_top_buttons_sensitive(self, sensitive):
+        self.button_top.set_sensitive(sensitive)
+        self.button_up.set_sensitive(sensitive)
+        
+    def __set_buttom_buttons_sensitive(self, sensitive):
+        self.button_down.set_sensitive(sensitive)
+        self.button_bottom.set_sensitive(sensitive)
     
     def on_disabled_module_changed(self, selection):
         module = self.disabledmoduleview.get_selected_module()
         
         if (len(self.disabledhandlers_box.get_children()) > 1):
             self.disabledhandlers_box.remove( self.disabledhandlers_box.get_children()[1] )
-        self.disabledhandlers_box.pack_end(InfoBox(module.INSTRUCTIONS, gtk.STOCK_DIALOG_ERROR), False, False, 0)
+        if hasattr(module, "INSTRUCTIONS") and module.INSTRUCTIONS != None and module.INSTRUCTIONS != "":
+            self.disabledhandlers_box.pack_end(InfoBox(module.INSTRUCTIONS, gtk.STOCK_DIALOG_ERROR), False, False, 0)
         self.disabledhandlers_box.show_all()
-     
-    def poll_requirements(self, module_context):
-        try:
-            if module_context != self.moduleview.get_selected_module():
-                return False
-        except AttributeError:
-            return False
-        self.check_requirements(module_context)
-        return True
-    
+  
     def check_requirements(self, module):
         if module is None:
             return
@@ -293,14 +295,15 @@ class DeskbarPreferences:
         self.old_info_message = message
         
         self.info_area.remove(self.info_area.get_children()[0])
-        if message == None or message == "":
-            self.info_area.add(self.default_info)
-            self.more_button.set_sensitive(False)
-        else:
+        
+        if callable(callback):
             other_info = InfoBox(message, stock_icon)
             self.info_area.add( other_info )
             other_info.show_all()
             self.more_button.set_sensitive(self.more_button_callback != None)
+        else:
+            self.info_area.add(self.default_info)
+            self.more_button.set_sensitive(False)
     
     def on_module_toggled(self, moduleview, module):
         if (module.is_enabled()):
@@ -394,22 +397,30 @@ class DeskbarPreferences:
     def on_button_top_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_to_top(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
     
     def on_button_up_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_up(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
     
     def on_button_down_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_down(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
     
     def on_button_bottom_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_to_bottom(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
         
     def update_gconf(self):
          # Update the gconf enabled modules settings
